@@ -1,15 +1,12 @@
 package Algorithm::Diff::Callback;
-{
-  $Algorithm::Diff::Callback::VERSION = '0.100';
-}
 # ABSTRACT: Use callbacks on computed differences
-
+$Algorithm::Diff::Callback::VERSION = '0.110';
 use strict;
 use warnings;
-
-use Carp;
 use parent          'Exporter';
-use List::MoreUtils 'uniq';
+
+use Carp            'croak';
+use List::Util 1.45 'uniq';
 use Algorithm::Diff 'diff';
 
 our @EXPORT_OK = qw(diff_hashes diff_arrays);
@@ -20,7 +17,7 @@ sub diff_hashes {
     ref $old eq 'HASH' or croak 'Arg 1 must be hashref';
     ref $new eq 'HASH' or croak 'Arg 2 must be hashref';
 
-    my @changed = ();
+    my @changed;
     foreach my $key ( keys %{$new} ) {
         if ( ! exists $old->{$key} ) {
             exists $cbs{'added'}
@@ -46,6 +43,8 @@ sub diff_hashes {
                 and $cbs{'changed'}->( $key, $before, $after );
         }
     }
+
+    return;
 }
 
 sub diff_arrays {
@@ -73,6 +72,8 @@ sub diff_arrays {
             }
         }
     }
+
+    return;
 }
 
 1;
@@ -81,13 +82,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Algorithm::Diff::Callback - Use callbacks on computed differences
 
 =head1 VERSION
 
-version 0.100
+version 0.110
 
 =head1 SYNOPSIS
 
@@ -267,7 +270,7 @@ Sawyer X <xsawyerx@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Sawyer X.
+This software is copyright (c) 2016 by Sawyer X.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
